@@ -181,3 +181,29 @@ class RasaConverter(DataConverter):
             self.synonym_data += self.__synonym_converter(data.entity_synonyms)
 
         self.post_process(dataset_type=dataset_type, output_directory=output_directory)
+
+    def component_convert(self, training_data: TrainingData, dataset_type: DatasetType):
+        self.nlu_data += self.__nlu_data_converter(training_data)
+        self.lookup_data += self.__lookup_converter(training_data.lookup_tables)
+        self.regex_data += self.__regex_converter(training_data.regex_features)
+        self.synonym_data += self.__synonym_converter(training_data.entity_synonyms)
+
+        if self.entity_mapping:
+            self.nlu_data = map_entities(self.nlu_data, self.entity_mapping)
+
+        if self.auto_tag_entities:
+            self.nlu_data = auto_tag_pretrained_entities(self.nlu_data, self.language)
+            self.nlu_data = auto_tag_lookup(self.nlu_data, self.lookup_data)
+            self.nlu_data = auto_tag_regex(self.nlu_data, self.regex_data)
+
+        self.set_data_type(dataset_type)
+        self.nlu_data = remove_nlu_duplicates(self.nlu_data)
+        self.lookup_data = remove_entity_duplicates(
+            remove_nlu_duplicates(self.lookup_data)
+        )
+        self.regex_data = remove_entity_duplicates(
+            remove_nlu_duplicates(self.regex_data)
+        )
+        self.synonym_data = remove_entity_duplicates(
+            remove_nlu_duplicates(self.synonym_data)
+        )
