@@ -210,3 +210,12 @@ def print_converted_data_inference(from_platform: Text, output_path: Path, conve
     console.print(f"{GREEN_TICK} ") if converter.regex_data else console.print(
         f"{CROSS} "
     )
+
+
+def print_model_ids(model_ids: List[Text]):
+    table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
+    table.add_column("Index")
+    table.add_column("Model Id")
+    for index, single_model_id in enumerate(model_ids):
+        table.add_row(str(index), single_model_id)
+    console.print(table)
