@@ -55,7 +55,6 @@ from neuralspace.constants import (
     neuralspace_url,
 )
 
-
 logger = logging.getLogger("rich")
 console = Console()
 
@@ -65,13 +64,13 @@ def setup_logger(log_level: Text):
     logging.basicConfig(level=log_level, handlers=[RichHandler(level=logging.INFO)])
     if log_level == "INFO":
         logger.level = logging.INFO
-        logging.getLogger('asyncio').setLevel(logging.INFO)
+        logging.getLogger("asyncio").setLevel(logging.INFO)
     elif log_level == "DEBUG":
         logger.level = logging.DEBUG
-        logging.getLogger('asyncio').setLevel(logging.DEBUG)
+        logging.getLogger("asyncio").setLevel(logging.DEBUG)
     elif log_level == "ERROR":
         logger.level = logging.ERROR
-        logging.getLogger('asyncio').setLevel(logging.ERROR)
+        logging.getLogger("asyncio").setLevel(logging.ERROR)
 
 
 def get_logo():
@@ -148,7 +147,6 @@ async def app_install(name: Text):
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            register_auth_token(json_response)
             console.print(f"> {INFO} {GREEN_TICK} Install Successful!")
             console.print(
                 f"{FAST_FORWARD} To use the {name} app: {DARK_ORANGE_START}neuralspace {name}{DARK_ORANGE_END} --help"
@@ -175,6 +173,7 @@ def get_list_chunks(items: List[Any], chunk_size: int):
 
 def add_apps_to_table(table: Table) -> Table:
     table.add_row(
+        f"{BOLD_START}NeuraLingo{BOLD_END}",
         f"{BOLD_START}nlu{BOLD_END}",
         "neuralspace [bold red]nlu[/bold red]",
         "Whether you are using chatbots, voicebots, or process automation engines, they are all powered by Natural "
@@ -186,6 +185,7 @@ def add_apps_to_table(table: Table) -> Table:
         "to the user in a more empathetic tone.",
     )
     table.add_row(
+        f"{BOLD_START}Entity Recognition{BOLD_END}",
         f"{BOLD_START}ner{BOLD_END}",
         "neuralspace [bold red]ner[/bold red]",
         "Entities play a major role in language understanding. To perform an action on a certain user query you not "
@@ -196,6 +196,7 @@ def add_apps_to_table(table: Table) -> Table:
         "Essentially any valuable information that can be extracted from text.",
     )
     table.add_row(
+        f"{BOLD_START}Machine Translation{BOLD_END}",
         f"{BOLD_START}translation{BOLD_END}",
         "neuralspace [bold red]translation[/bold red]",
         "Whether we are talking about subtitles, government documents or question papers for exams, all of them "
@@ -206,6 +207,7 @@ def add_apps_to_table(table: Table) -> Table:
         "translate text in over 100 languages. ",
     )
     table.add_row(
+        f"{BOLD_START}Transliteration{BOLD_END}",
         f"{BOLD_START}transliteration{BOLD_END}",
         "neuralspace [bold red]transliteration[/bold red]",
         "For languages that don't use the latin script, e.g., Arabic, Hindi, Punjabi, Sinhala and many "
@@ -217,6 +219,7 @@ def add_apps_to_table(table: Table) -> Table:
         "alphabet to the other phonetically. ",
     )
     table.add_row(
+        f"{BOLD_START}NeuralAug{BOLD_END}",
         f"{BOLD_START}augmentation{BOLD_END}",
         "neuralspace [bold red]augmentation[/bold red]",
         "Any language processing task requires data, and we all wish we could generate data "
@@ -225,6 +228,7 @@ def add_apps_to_table(table: Table) -> Table:
         "can help in creating datasets faster and make language processing models more robust. ",
     )
     table.add_row(
+        f"{BOLD_START}Language Detection{BOLD_END}",
         f"{BOLD_START}language-detection{BOLD_END}",
         "neuralspace [bold red]language-detection[/bold red]",
         "Dealing with different languages poses a fundamental problem of first detecting what language "
@@ -236,7 +240,8 @@ def add_apps_to_table(table: Table) -> Table:
 
 
 def add_heading_to_description_table(table: Table) -> Table:
-    table.add_column("Name", style="#c47900")
+    table.add_column("App Name", style="#c47900")
+    table.add_column("App Code", style="#c47900")
     table.add_column("Command", style="#c47900")
     table.add_column("Description")
     return table
